==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/LaunchTemplateInstanceRequirementsVcpuCountArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsVcpuCountArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property max Maximum.
 * @property min Minimum.
 */
public data class LaunchTemplateInstanceRequirementsVcpuCountArgs(
    public val max: Output<Int>? = null,
    public val min: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsVcpuCountArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsVcpuCountArgs =
        com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsVcpuCountArgs.builder()
            .max(max?.applyValue({ args0 -> args0 }))
            .min(min.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LaunchTemplateInstanceRequirementsVcpuCountArgs].
 */
@PulumiTagMarker
public class LaunchTemplateInstanceRequirementsVcpuCountArgsBuilder internal constructor() {
    private var max: Output<Int>? = null

    private var min: Output<Int>? = null

    /**
     * @param value Maximum.
     */
    @JvmName("fhbqxdgbbspwtdoo")
    public suspend fun max(`value`: Output<Int>) {
        this.max = value
    }

    /**
     * @param value Minimum.
     */
    @JvmName("xdbkdurasejcwgks")
    public suspend fun min(`value`: Output<Int>) {
        this.min = value
    }

    /**
     * @param value Maximum.
     */
    @JvmName("jhcbknwjfullpnjw")
    public suspend fun max(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.max = mapped
    }

    /**
     * @param value Minimum.
     */
    @JvmName("arhxnjiprpqrjyyu")
    public suspend fun min(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.min = mapped
    }

    internal fun build(): LaunchTemplateInstanceRequirementsVcpuCountArgs =
        LaunchTemplateInstanceRequirementsVcpuCountArgs(
            max = max,
            min = min ?: throw PulumiNullFieldException("min"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/LaunchTemplateInstanceRequirementsVcpuCountArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsVcpuCountArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property max Maximum.
 * @property min Minimum.
 */
public data class LaunchTemplateInstanceRequirementsVcpuCountArgs(
    public val max: Output<Int>? = null,
    public val min: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsVcpuCountArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsVcpuCountArgs =
        com.pulumi.aws.ec2.inputs.LaunchTemplateInstanceRequirementsVcpuCountArgs.builder()
            .max(max?.applyValue({ args0 -> args0 }))
            .min(min.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LaunchTemplateInstanceRequirementsVcpuCountArgs].
 */
@PulumiTagMarker
public class LaunchTemplateInstanceRequirementsVcpuCountArgsBuilder internal constructor() {
    private var max: Output<Int>? = null

    private var min: Output<Int>? = null

    /**
     * @param value Maximum.
     */
    @JvmName("qpkkppcslqrgfcqh")
    public suspend fun max(`value`: Output<Int>) {
        this.max = value
    }

    /**
     * @param value Minimum.
     */
    @JvmName("rqnfkrboyfonrnsa")
    public suspend fun min(`value`: Output<Int>) {
        this.min = value
    }

    /**
     * @param value Maximum.
     */
    @JvmName("pdnodxvxxwlysnhu")
    public suspend fun max(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.max = mapped
    }

    /**
     * @param value Minimum.
     */
    @JvmName("oestbbppwydvwybg")
    public suspend fun min(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.min = mapped
    }

    internal fun build(): LaunchTemplateInstanceRequirementsVcpuCountArgs =
        LaunchTemplateInstanceRequirementsVcpuCountArgs(
            max = max,
            min = min ?: throw PulumiNullFieldException("min"),
        )
}
